@@ -462,3 +462,35 @@ def launchAiServiceInstallPipeline(dynClient: DynamicClient, params: dict) -> st
 
     pipelineURL = f"{getConsoleURL(dynClient)}/k8s/ns/aiservice-{instanceId}-pipelines/tekton.dev~v1beta1~PipelineRun/{instanceId}-install-{timestamp}"
     return pipelineURL
+
+
+def launchAiServiceUpgradePipeline(dynClient: DynamicClient,
+                                   aiserviceInstanceId: str,
+                                   skipPreCheck: bool = False,
+                                   aiserviceChannel: str = "",
+                                   params: dict = {}) -> str:
+    """
+    Create a PipelineRun to upgrade the chosen AI Service instance
+    """
+    pipelineRunsAPI = dynClient.resources.get(api_version="tekton.dev/v1beta1", kind="PipelineRun")
+    namespace = f"aiservice-{aiserviceInstanceId}-pipelines"
+    timestamp = datetime.now().strftime("%y%m%d-%H%M")
+    # Create the PipelineRun
+    templateDir = path.join(path.abspath(path.dirname(__file__)), "templates")
+    env = Environment(
+        loader=FileSystemLoader(searchpath=templateDir)
+    )
+    template = env.get_template("pipelinerun-aiservice-upgrade.yml.j2")
+    renderedTemplate = template.render(
+        timestamp=timestamp,
+        aiservice_instance_id=aiserviceInstanceId,
+        skip_pre_check=skipPreCheck,
+        aiservice_channel=aiserviceChannel,
+        **params
+    )
+    logger.debug(renderedTemplate)
+    pipelineRun = yaml.safe_load(renderedTemplate)
+    pipelineRunsAPI.apply(body=pipelineRun, namespace=namespace)
+
+    pipelineURL = f"{getConsoleURL(dynClient)}/k8s/ns/aiservice-{aiserviceInstanceId}-pipelines/tekton.dev~v1beta1~PipelineRun/{aiserviceInstanceId}-upgrade-{timestamp}"
+    return pipelineURL
